@@ -11,7 +11,6 @@ as it will be run under the user's environment.
 from __future__ import absolute_import, division, print_function
 
 import os
-import sys
 import imp
 import inspect
 import logging
@@ -35,7 +34,6 @@ try:
     constants_mod = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(constants_mod)
 except AttributeError:
-    import imp
     constants_mod = imp.load_source('constants',constants_path)
 constants = constants_mod.constants
 
@@ -44,6 +42,7 @@ try:
 except NameError:
     String = str
 
+
 def get_args():
     """Read json of [args, kwargs] from the std args file"""
     with open(constants['args']) as f:
@@ -51,6 +50,7 @@ def get_args():
         logging.debug('get_args raw: %r',data)
         return json_decode(data)
 
+
 def unicode_to_ascii(obj):
     if isinstance(obj,String):
         return str(obj)
@@ -66,6 +66,7 @@ def unicode_to_ascii(obj):
     else:
         return obj
 
+
 def run(classname, filename=None, args=False, debug=False):
     logging.basicConfig(level=logging.DEBUG if debug else logging.WARN)
     logging.warning('exe_helper(%s)', classname)
@@ -92,7 +93,7 @@ def run(classname, filename=None, args=False, debug=False):
         class_obj = getattr(mod,cl)
 
     if (inspect.isclass(class_obj) and
-        any(True for c in inspect.getmro(class_obj) if c.__name__ == 'IPBaseClass')):
+            any(True for c in inspect.getmro(class_obj) if c.__name__ == 'IPBaseClass')):
         logging.info('IceProd v1 class')
         instance = class_obj()
         for k in class_args['kwargs']:
@@ -107,6 +108,7 @@ def run(classname, filename=None, args=False, debug=False):
         logging.info('regular callable')
         class_obj(*class_args['args'],**class_args['kwargs'])
 
+
 def main():
     import argparse
     parser = argparse.ArgumentParser(description='IceProd Core')
@@ -126,5 +128,6 @@ def main():
             pickle.dump(e,f)
         raise
 
+
 if __name__ == '__main__':
     main()
