@@ -1,4 +1,4 @@
-import os
+
 page_template = '''
     <h1>%s</h1>
     <p class = "desc">
@@ -11,7 +11,8 @@ page_template = '''
 
     '''
 
-#       Converts ##LinkName## in string to html linkds
+
+# Converts ##LinkName## in string to html linkds
 def add_links(desc):
     d = desc.split('##')
     is_link = False
@@ -24,29 +25,29 @@ def add_links(desc):
         is_link = not is_link
     return desc
 
-#       Loads and parses documentation file
+
+# Loads and parses documentation file
 def load_doc(filename):
     try:
         f = open(filename.lower()+'.txt', 'rt')
     except IOError:
         return 'Not found'
     lines = []
-    for l in f.readlines():
-        if len(l.strip()):
-            lines.append(l)
+    for line in f.readlines():
+        if len(line.strip()):
+            lines.append(line)
 
     body = ''
-    for l in lines[1:]:
-        nd = l.split(None, 1)
+    for line in lines[1:]:
+        nd = line.split(None, 1)
         name = nd[0]
         desc = nd[1] if len(nd) == 2 else ''
         desc = add_links(desc)
         body += '<li><h3>%s</h3><p>%s</p></li>' % (name, desc)
 
-
     nd = lines[0].split(None, 1)
     name = nd[0]
     desc = nd[1] if len(nd) == 2 else ''
     f.close()
-    
-    return page_template %(name, desc, body)
\ No newline at end of file
+
+    return page_template % (name, desc, body)
